From e5b5162b77d5b8929ad388797c845ffaaba6c306 Mon Sep 17 00:00:00 2001
From: thomascube <thomas@roundcube.net>
Date: Tue, 08 May 2012 06:06:30 -0400
Subject: [PATCH] Upgraded to PEAR::Mail_Mime 1.8.3

---
 program/include/rcube_message.php |   68 ++++++++++++++++++++++++++--------
 1 files changed, 52 insertions(+), 16 deletions(-)

diff --git a/program/include/rcube_message.php b/program/include/rcube_message.php
index d0959ef..58f8510 100644
--- a/program/include/rcube_message.php
+++ b/program/include/rcube_message.php
@@ -164,11 +164,13 @@
     /**
      * Get content of a specific part of this message
      *
      * @param string $mime_id Part MIME-ID
      * @param resource $fp File pointer to save the message part
      * @return string Part content
      */
-    public function get_part_content($mime_id, $fp=NULL)
+    public function get_part_content($mime_id, $fp = null, $skip_charset_conv = false)
     {
         if ($part = $this->mime_parts[$mime_id]) {
             // stored in message structure (winmail/inline-uuencode)
@@ -179,7 +181,7 @@
                 return $fp ? true : $part->body;
             }
             // get from IMAP
-            return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp);
+            return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp, $skip_charset_conv);
         } else
             return null;
     }
@@ -188,15 +190,36 @@
     /**
      * Determine if the message contains a HTML part
      *
+     * @param bool $recursive Enables checking in all levels of the structure
+     *
      * @return bool True if a HTML is available, False if not
      */
-    function has_html_part()
+    function has_html_part($recursive = true)
     {
         // check all message parts
-        foreach ($this->parts as $pid => $part) {
-            $mimetype = strtolower($part->ctype_primary . '/' . $part->ctype_secondary);
-            if ($mimetype == 'text/html')
+        foreach ($this->parts as $part) {
+            if ($part->mimetype == 'text/html') {
+                // Level check, we'll skip e.g. HTML attachments
+                if (!$recursive) {
+                    $level = explode('.', $part->mime_id);
+
+                    // Level too high
+                    if (count($level) > 2) {
+                        continue;
+                    }
+
+                    // HTML part can be on the lower level, if not...
+                    if (count($level) > 1) {
+                        // It can be an alternative or related message part
+                        $parent = $this->mime_parts[0];
+                        if ($parent->mimetype != 'multipart/alternative' && $parent->mimetype != 'multipart/related') {
+                            continue;
+                        }
+                    }
+                }
+
                 return true;
+            }
         }
 
         return false;
@@ -211,10 +234,9 @@
     function first_html_part()
     {
         // check all message parts
-        foreach ($this->mime_parts as $mime_id => $part) {
-            $mimetype = strtolower($part->ctype_primary . '/' . $part->ctype_secondary);
-            if ($mimetype == 'text/html') {
-                return $this->get_part_content($mime_id);
+        foreach ($this->mime_parts as $pid => $part) {
+            if ($part->mimetype == 'text/html') {
+                return $this->get_part_content($pid);
             }
         }
     }
@@ -234,12 +256,10 @@
 
         // check all message parts
         foreach ($this->mime_parts as $mime_id => $part) {
-            $mimetype = $part->ctype_primary . '/' . $part->ctype_secondary;
-
-            if ($mimetype == 'text/plain') {
+            if ($part->mimetype == 'text/plain') {
                 return $this->get_part_content($mime_id);
             }
-            else if ($mimetype == 'text/html') {
+            else if ($part->mimetype == 'text/html') {
                 $out = $this->get_part_content($mime_id);
 
                 // remove special chars encoding
@@ -664,4 +684,20 @@
 
         return $parts;
     }
+
+
+    /**
+     * Deprecated methods (to be removed)
+     */
+
+    public static function unfold_flowed($text)
+    {
+        return rcube_mime::unfold_flowed($text);
+    }
+
+    public static function format_flowed($text, $length = 72)
+    {
+        return rcube_mime::format_flowed($text, $length);
+    }
+
 }
@@ -164,11 +164,13 @@
      * Get content of a specific part of this message
      *
-     * @param string $mime_id Part MIME-ID
-     * @param resource $fp File pointer to save the message part
+     * @param string   $mime_id           Part MIME-ID
+     * @param resource $fp File           pointer to save the message part
+     * @param boolean  $skip_charset_conv Disables charset conversion
+     *
      * @return string Part content
      */

--
Gitblit v1.9.1